The unified diff between revisions [24fb0b25..] and [8032bf83..] is displayed below. It can also be downloaded as a raw diff.

This diff has been restricted to the following files: 'tests/clone_validates_target_directory/__driver__.lua'

#
#
# patch "tests/clone_validates_target_directory/__driver__.lua"
#  from [ca4db9a9677e80a1015f129f8cbaf4face246a58]
#    to [bb4ba95dd27e59251ea97e3e108800223c52874a]
#
============================================================
--- tests/clone_validates_target_directory/__driver__.lua	ca4db9a9677e80a1015f129f8cbaf4face246a58
+++ tests/clone_validates_target_directory/__driver__.lua	bb4ba95dd27e59251ea97e3e108800223c52874a
@@ -17,9 +17,10 @@ if existsonpath("chmod") and existsonpat

 if existsonpath("chmod") and existsonpath("test") then
   -- skip this part if run as root (hi Gentoo!)
   -- Also skip if on Windows, since these permissions are not enforced there
   if check({"test", "-O", "/"}, false, false, false) == 0 or
-     ostype == "Windows"
+     ostype == "Windows" or
+     string.find (ostype, "CYGWIN")
   then
     partial_skip = true
   else
@@ -17,9 +17,10 @@ if existsonpath("chmod") and existsonpat
 if existsonpath("chmod") and existsonpath("test") then
   -- skip this part if run as root (hi Gentoo!)
-  -- Also skip if on Windows, since these permissions are not enforced there
+  -- Also skip if on Windows and Cygwin, since these permissions are not enforced there
   if check({"test", "-O", "/"}, false, false, false) == 0 or